@@ -63,7 +63,7 @@ def test_get_successful():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -100,8 +100,9 @@ def test_get_successful_authenticated():
         "format": format,
         "full_page": random.choice([True, False]),
         "width": fake.random_int(),
+        "header": ["header1=value1", "header2=value2"],
     }
-    url_encoded_options = urllib.parse.urlencode(options)
+    url_encoded_options = urllib.parse.urlencode(options, doseq=True)
 
     token = (
         hmac.new(
@@ -208,7 +209,7 @@ def test_get_successful_white_space_url():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options_parsed)}"
+        f"?{urllib.parse.urlencode(options_parsed, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -245,7 +246,7 @@ def test_get_successful_without_setting_format():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/png"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -291,7 +292,7 @@ def test_get_successful_missing_schema_url():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options_parsed)}"
+        f"?{urllib.parse.urlencode(options_parsed, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -354,7 +355,7 @@ def test_get_with_different_host_name():
     urlbox_request_url = (
         f"https://{api_host_name}/"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key, api_host_name=api_host_name)
@@ -391,7 +392,7 @@ def test_get_successful_with_html_not_url():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -426,7 +427,7 @@ def test_get_unsuccessful_without_html_not_url():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -453,7 +454,7 @@ def test_delete_request():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -489,7 +490,7 @@ def test_head_request():
     urlbox_request_url = (
         f"{UrlboxClient.BASE_API_URL}"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key)
@@ -529,7 +530,7 @@ def test_head_with_different_host_name():
     urlbox_request_url = (
         f"https://{api_host_name}/"
         f"{api_key}/{format}"
-        f"?{urllib.parse.urlencode(options)}"
+        f"?{urllib.parse.urlencode(options, doseq=True)}"
     )
 
     urlbox_client = UrlboxClient(api_key=api_key, api_host_name=api_host_name)
